import greenfoot.*;  // (World, Actor, GreenfootImage, and Greenfoot)

/**
 * A key for a piano.
 * 
 * @author: M. Kolling, Ed Parrish
 * @version 1.0  11/15/2010
 */
public class Key extends Actor
{
    private boolean isDown;
    private String key;
    private String sound;
    private GreenfootImage upImage;
    private GreenfootImage downImage;
    private Piano piano;

    /**
     * Create a new key linked to a keyboard key and 
     * with a given sound.
     */
    public Key(String keyName, String soundFile, GreenfootImage imUp, 
    GreenfootImage imDown)
    {
        key = keyName;
        sound = soundFile;
        upImage = imUp;
        downImage = imDown;
        setImage(upImage);
    }

    /**
     * Do the action for this key.
     */
    public void act()
    {
        piano = (Piano) getWorld();
        if (!isDown && Greenfoot.isKeyDown(key)) 
        {
            play();
        }
        if (isDown && !Greenfoot.isKeyDown(key) && !piano.getAutoPlay()) 
        {
            stop();
        }
    }

    /**
     * Play the note of this key
     */
    public void play()
    {
        setImage(downImage);
        isDown = true;
        Greenfoot.playSound(sound);
    }

    /**
     * Stop playing the note of this key
     */
    public void stop()
    {
        setImage(upImage);
        isDown = false;
    }
}