import java.awt.*;
import java.awt.image.BufferedImage;
import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)

/**
 * A label for writing text.
 * 
 * @author Ed Parrish 
 * @version 1.1  11/22/2010
 */
public class Label extends Actor
{
    /**
     * Constructs a transparent image with the specified text 
     * displayed in the default color.
     *
     * @param text The text to display on the label
     */
    public Label(String text)
    {
        this(text, null);
    }

    /**
     * Constructs a transparent image with text embedded in the 
     * specified color.
     *
     * @param text The text to display on the label
     * @param color The color with which to write the text.
     */
    public Label(String text, Color color)
    {
        GreenfootImage dummy = new GreenfootImage(2, 2);
        BufferedImage bim = dummy.getAwtImage();
        Graphics g = bim.getGraphics();
        FontMetrics fm = g.getFontMetrics();
        int width = fm.stringWidth(text);
        int height = fm.getHeight(); 
        GreenfootImage img = new GreenfootImage(width, height);
        if (color != null)
        {
            img.setColor(color);
        }
        img.drawString(text, 0, fm.getAscent());
        setImage(img);
    }
}
