import java.util.ArrayList;

/**
 * Represents a single song, which is a collection of notes.
 * 
 * @author Ed Parrish
 * @version 1.0  11/15/2010
 */
public class Song  
{
    private int clockTick;
    private boolean playing;
    private ArrayList<Note> list;
    private int duration;
    Piano piano;

    /**
     * Constructor for objects of class Song
     */
    public Song()
    {
        list = new ArrayList<Note>();
    }

    /**
     * Add a Note to the song
     * 
     * @param  newNote   the note to add
     */
    public void addNote(Note newNote)
    {
        list.add(newNote);
        calcDuration();
    }

    /**
     * Calculates the total duration of the song.
     */
    private void calcDuration()
    {
        int maxStartTime = 0;
        int maxStartTimeDuration = 0;
        for (Note note : list) 
        {
            int startTick = note.getStartTick();
            if (startTick > maxStartTime)
            {
                maxStartTime = startTick;
                maxStartTimeDuration = note.getDuration();
            }
        }
        duration = maxStartTime + maxStartTimeDuration;
    }

    /**
     * Update the song's progression.
     */
    public void update()
    {
        if (playing) 
        {
            for (Note note : list) 
            {
                note.play(clockTick);
            }
            clockTick++;
            if (clockTick >= duration)
            {
                stop();
            }
        }
    }

    /**
     * Start playing this Song.
     */
    public void play(Piano p)
    {
        playing =  true;
        piano = p;
        piano.setAutoPlay(true);
        if (clockTick != 0) 
        {
            clockTick = 0;
        }
    }

    /**
     * Stop playing this Song.
     */
    public void stop()
    {
        playing =  false;
        piano.setAutoPlay(false);
        for (Note note : list) 
        {
            note.stop();
        }

    }

    /**
     * Tests whether this Song is playing or not.
     *
     * @return true if playing; otherwise false.
     */
    public boolean isPlaying()
    {
        return playing;
    }
}
